use crate::quantity::{Quantity, Value};
use generate_quantity::quantity_type;

use super::KILO;

//----- Pascals ----------------------------------
quantity_type! {Pascals, "Pa"}

impl<V: Value> Pascals<V> {
    #[inline]
    pub fn to_kilo_pascals(self) -> KiloPascals<V> {
        let divisor = V::from_u16(KILO).unwrap();
        KiloPascals(self.0 / divisor)
    }
}

//----- Kilopascals ----------------------------------
quantity_type! {KiloPascals, "kPa"}

impl<V: Value> KiloPascals<V> {
    #[inline]
    pub fn to_pascals(self) -> Pascals<V> {
        let multiplier = V::from_u16(KILO).unwrap();
        Pascals(self.0 * multiplier)
    }
}

// ---------------------------------------------------------------------------------------------------------------------
// ----- Tests ------------------------
// ---------------------------------------------------------------------------------------------------------------------
#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn convert_u32() {
        let pascals: Pascals<u32> = 1_000.pascals();
        let kilo_pascals: KiloPascals<u32> = 1.kilo_pascals();

        assert_eq!(pascals.0, kilo_pascals.to_pascals().0);
        assert_eq!(kilo_pascals.0, pascals.to_kilo_pascals().0);
    }
}
